# MySQL/MariaDB communicate tool
![Jugo](https://i.imgur.com/DM1NSFt.png)

![](https://img.shields.io/badge/python-3.7-blue.svg) ![](https://img.shields.io/badge/version-0.0.4-green.svg)

## What is it?
It implementation of Django QuerySet, which you can use without Django

## How to use
Read wik: https://github.com/ThreadShakur/Jugo/wiki
